@@ -17,6 +17,8 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
+from __future__ import print_function
+
 import os
 import re
 import socket
@@ -24,35 +26,38 @@ import sys
 import subprocess
 import time
 import types
-import cPickle
+import pickle
 import logging
 from optparse import make_option
-try:
-    from cStringIO import StringIO
-except ImportError:
-    from StringIO import StringIO
-
-try:
-    import elementtree.ElementTree as ET
-except ImportError:
-    import xml.etree.ElementTree as ET
+import xml.etree.ElementTree as ET
 
 try:
     import curses
 except ImportError:
     curses = None
 
-from jhbuild.errors import FatalError
 import jhbuild.moduleset
+from jhbuild.errors import CommandError
 from jhbuild.commands import Command, register_command
-from jhbuild.utils import httpcache
+from jhbuild.utils import httpcache, cmds, _, open_text
 from jhbuild.modtypes import MetaModule
+from jhbuild.utils.compat import TextIO
 
-try: t_bold = cmds.get_output(['tput', 'bold'])
-except: t_bold = ''
-try: t_reset = cmds.get_output(['tput', 'sgr0'])
-except: t_reset = ''
+try:
+    t_bold = cmds.get_output(['tput', 'bold'])
+except CommandError:
+    try:
+        t_bold = cmds.get_output(['tput', 'md'])
+    except CommandError:
+        t_bold = ''
 
+try:
+    t_reset = cmds.get_output(['tput', 'sgr0'])
+except CommandError:
+    try:
+        t_reset = cmds.get_output(['tput', 'me'])
+    except CommandError:
+        t_reset = ''
 
 HTML_AT_TOP = '''<html>
 <head>
@@ -137,7 +142,7 @@ class Check:
     def fix_false_positive(self, false_positive):
         if not false_positive:
             return
-        if false_positive ==  'n/a':
+        if false_positive == 'n/a':
             raise ExcludedModuleException()
         self.status = 'ok'
 
@@ -194,7 +199,7 @@ class SymbolsCheck(Check):
                 filenames = [x for x in filenames if \
                              os.path.splitext(x)[-1] in ('.c', '.cc', '.cpp', '.h', '.glade')]
                 for filename in filenames:
-                    for s in symbol_regex.findall(file(os.path.join(base, filename)).read()):
+                    for s in symbol_regex.findall(open(os.path.join(base, filename)).read()):
                         deprecated_and_used[s] = True
         except UnicodeDecodeError:
             raise ExcludedModuleException()
@@ -247,7 +252,7 @@ class GrepCheck(Check):
                 filenames = [x for x in filenames if \
                              os.path.splitext(x)[-1] in ('.c', '.cc', '.cpp', '.h', '.glade')]
                 for filename in filenames:
-                    if self.grep in file(os.path.join(base, filename)).read():
+                    if self.grep in open(os.path.join(base, filename)).read():
                         self.nb_occurences += 1
         except UnicodeDecodeError:
             raise ExcludedModuleException()
@@ -304,7 +309,8 @@ class FilenamesCheck(Check):
 class DeprecatedSymbolsCheck(SymbolsCheck):
     cached_symbols = {}
 
-    def load_deprecated_symbols(self):
+    @property
+    def symbols(self):
         if self.cached_symbols.get(self.devhelp_filenames):
             return self.cached_symbols.get(self.devhelp_filenames)
         symbols = []
@@ -312,16 +318,15 @@ class DeprecatedSymbolsCheck(SymbolsCheck):
             try:
                 devhelp_path = os.path.join(self.config.devhelp_dirname, devhelp_filename)
                 tree = ET.parse(devhelp_path)
-            except:
+            except Exception:
                 raise CouldNotPerformCheckException()
             for keyword in tree.findall('//{http://www.devhelp.net/book}keyword'):
-                if not keyword.attrib.has_key('deprecated'):
+                if 'deprecated' not in keyword.attrib:
                     continue
                 name = keyword.attrib.get('name').replace('enum ', '').replace('()', '').strip()
                 symbols.append(name)
         DeprecatedSymbolsCheck.cached_symbols[self.devhelp_filenames] = symbols
         return symbols
-    symbols = property(load_deprecated_symbols)
 
 
 class cmd_goalreport(Command):
@@ -363,12 +368,12 @@ class cmd_goalreport(Command):
 
     def run(self, config, options, args, help=None):
         if options.output:
-            output = StringIO()
+            output = TextIO()
             global curses
             if curses and config.progress_bar:
                 try:
                     curses.setupterm()
-                except:
+                except Exception:
                     curses = None
         else:
             output = sys.stdout
@@ -386,8 +391,7 @@ class cmd_goalreport(Command):
         if options.list_all_modules:
             self.module_list = module_set.modules.values()
         else:
-            self.module_list = module_set.get_module_list(args or config.modules,
-                            config.skip, process_sysdeps=False)
+            self.module_list = module_set.get_module_list(args or config.modules, config.skip)
 
         results = {}
         try:
@@ -396,8 +400,8 @@ class cmd_goalreport(Command):
             cachedir = os.path.join(os.environ['HOME'], '.cache','jhbuild')
         if options.cache:
             try:
-                results = cPickle.load(file(os.path.join(cachedir, options.cache)))
-            except:
+                results = pickle.load(open(os.path.join(cachedir, options.cache), "rb"))
+            except Exception:
                 pass
 
         self.repeat_row_header = 0
@@ -407,7 +411,7 @@ class cmd_goalreport(Command):
         for module_num, mod in enumerate(self.module_list):
             if mod.type in ('meta', 'tarball'):
                 continue
-            if not mod.branch or not mod.branch.repository.__class__.__name__ in (
+            if not mod.branch or mod.branch.repository.__class__.__name__ not in (
                     'SubversionRepository', 'GitRepository'):
                 if not mod.moduleset_name.startswith('gnome-external-deps'):
                     continue
@@ -418,7 +422,7 @@ class cmd_goalreport(Command):
             tree_id = mod.branch.tree_id()
             valid_cache = (tree_id and results.get(mod.name, {}).get('tree-id') == tree_id)
 
-            if not mod.name in results:
+            if mod.name not in results:
                 results[mod.name] = {
                     'results': {}
                 }
@@ -454,25 +458,26 @@ class cmd_goalreport(Command):
         if not os.path.exists(cachedir):
             os.makedirs(cachedir)
         if options.cache:
-            cPickle.dump(results, file(os.path.join(cachedir, options.cache), 'w'))
+            pickle.dump(results, open(os.path.join(cachedir, options.cache), 'wb'))
 
-        print >> output, HTML_AT_TOP % {'title': self.title}
+        print(HTML_AT_TOP % {'title': self.title}, file=output)
         if self.page_intro:
-            print >> output, self.page_intro
-        print >> output, '<table>'
-        print >> output, '<thead>'
-        print >> output, '<tr><td></td>'
+            print(self.page_intro, file=output)
+        print('<table>', file=output)
+        print('<thead>', file=output)
+        print('<tr><td></td>', file=output)
         for check in self.checks:
-            print >> output, '<th>%s</th>' % check.__name__
-        print >> output, '<td></td></tr>'
+            print('<th>%s</th>' % check.__name__, file=output)
+        print('<td></td></tr>', file=output)
         if [x for x in self.checks if x.header_note]:
-            print >> output, '<tr><td></td>'
+            print('<tr><td></td>', file=output)
             for check in self.checks:
-                print >> output, '<td>%s</td>' % (check.header_note or '')
-            print >> output, '</tr>'
-        print >> output, '</thead>'
-        print >> output, '<tbody>'
+                print('<td>%s</td>' % (check.header_note or ''), file=output)
+            print('</tr>', file=output)
+        print('</thead>', file=output)
+        print('<tbody>', file=output)
 
+        processed_modules = {'gnome-common': True}
         suites = []
         for module_key, module in module_set.modules.items():
             if not isinstance(module_set.get_module(module_key), MetaModule):
@@ -480,7 +485,7 @@ class cmd_goalreport(Command):
             if module_key.endswith('upcoming-deprecations'):
                 # mark deprecated modules as processed, so they don't show in "Others"
                 try:
-                    metamodule = module_set.get_module(meta_key)
+                    metamodule = module_set.get_module(module_key)
                 except KeyError:
                     continue
                 for module_name in metamodule.dependencies:
@@ -488,85 +493,83 @@ class cmd_goalreport(Command):
             else:
                 suites.append([module_key, module_key.replace('meta-', '')])
 
-        processed_modules = {'gnome-common': True}
-
         not_other_module_names = []
         for suite_key, suite_label in suites:
             metamodule = module_set.get_module(suite_key)
             module_names = [x for x in metamodule.dependencies if x in results]
             if not module_names:
                 continue
-            print >> output, '<tr><td class="heading" colspan="%d">%s</td></tr>' % (
-                    1+len(self.checks)+self.repeat_row_header, suite_label)
+            print('<tr><td class="heading" colspan="%d">%s</td></tr>' % (
+                    1+len(self.checks)+self.repeat_row_header, suite_label), file=output)
             for module_name in module_names:
                 if module_name in not_other_module_names:
                     continue
                 r = results[module_name].get('results')
-                print >> output, self.get_mod_line(module_name, r)
+                print(self.get_mod_line(module_name, r), file=output)
                 processed_modules[module_name] = True
             not_other_module_names.extend(module_names)
 
         external_deps = [x for x in results.keys() if \
                          x in [y.name for y in self.module_list] and \
-                         not x in processed_modules and \
+                         x not in processed_modules and \
                          module_set.get_module(x).moduleset_name.startswith('gnome-external-deps')]
         if external_deps:
-            print >> output, '<tr><td class="heading" colspan="%d">%s</td></tr>' % (
-                    1+len(self.checks)+self.repeat_row_header, 'External Dependencies')
+            print('<tr><td class="heading" colspan="%d">%s</td></tr>' % (
+                    1+len(self.checks)+self.repeat_row_header, 'External Dependencies'), file=output)
             for module_name in sorted(external_deps):
-                if not module_name in results:
+                if module_name not in results:
                     continue
                 r = results[module_name].get('results')
                 try:
                     version = module_set.get_module(module_name).branch.version
-                except:
+                except Exception:
                     version = None
-                print >> output, self.get_mod_line(module_name, r, version_number=version)
+                print(self.get_mod_line(module_name, r, version_number=version), file=output)
 
         other_module_names = [x for x in results.keys() if \
-                              not x in processed_modules and not x in external_deps]
+                              x not in processed_modules and x not in external_deps]
         if other_module_names:
-            print >> output, '<tr><td class="heading" colspan="%d">%s</td></tr>' % (
-                    1+len(self.checks)+self.repeat_row_header, 'Others')
+            print('<tr><td class="heading" colspan="%d">%s</td></tr>' % (
+                    1+len(self.checks)+self.repeat_row_header, 'Others'), file=output)
             for module_name in sorted(other_module_names):
-                if not module_name in results:
+                if module_name not in results:
                     continue
                 r = results[module_name].get('results')
-                print >> output, self.get_mod_line(module_name, r)
-        print >> output, '</tbody>'
-        print >> output, '<tfoot>'
+                print(self.get_mod_line(module_name, r), file=output)
+        print('</tbody>', file=output)
+        print('<tfoot>', file=output)
 
-        print >> output, '<tr><td></td>'
+        print('<tr><td></td>', file=output)
         for check in self.checks:
-            print >> output, '<th>%s</th>' % check.__name__
-        print >> output, '<td></td></tr>'
+            print('<th>%s</th>' % check.__name__, file=output)
+        print('<td></td></tr>', file=output)
 
-        print >> output, self.get_stat_line(results, not_other_module_names)
-        print >> output, '</tfoot>'
-        print >> output, '</table>'
+        print(self.get_stat_line(results, not_other_module_names), file=output)
+        print('</tfoot>', file=output)
+        print('</table>', file=output)
 
         if (options.bugfile and options.bugfile.startswith('http://')) or \
                 (options.falsepositivesfile and options.falsepositivesfile.startswith('http://')):
-            print >> output, '<div id="data">'
-            print >> output, '<p>The following data sources are used:</p>'
-            print >> output, '<ul>'
+            print('<div id="data">', file=output)
+            print('<p>The following data sources are used:</p>', file=output)
+            print('<ul>', file=output)
             if options.bugfile.startswith('http://'):
-                print >> output, '  <li><a href="%s">Bugs</a></li>' % options.bugfile
+                print('  <li><a href="%s">Bugs</a></li>' % options.bugfile, file=output)
             if options.falsepositivesfile.startswith('http://'):
-                print >> output, '  <li><a href="%s">False positives</a></li>' % options.falsepositivesfile
-            print >> output, '</ul>'
-            print >> output, '</div>'
+                print('  <li><a href="%s">False positives</a></li>' % options.falsepositivesfile, file=output)
+            print('</ul>', file=output)
+            print('</div>', file=output)
 
-        print >> output, '<div id="footer">'
-        print >> output, 'Generated:', time.strftime('%Y-%m-%d %H:%M:%S %z')
-        print >> output, 'on ', socket.getfqdn()
-        print >> output, '</div>'
+        print('<div id="footer">', file=output)
+        print('Generated:', time.strftime('%Y-%m-%d %H:%M:%S %z'), file=output)
+        print('on ', socket.getfqdn(), file=output)
+        print('</div>', file=output)
 
-        print >> output, '</body>'
-        print >> output, '</html>'
+        print('</body>', file=output)
+        print('</html>', file=output)
 
         if output != sys.stdout:
-            file(options.output, 'w').write(output.getvalue())
+            open_text(options.output, 'w').write(output.getvalue())
 
         if output != sys.stdout and config.progress_bar:
             sys.stdout.write('\n')
@@ -645,7 +648,7 @@ class cmd_goalreport(Command):
             nb_with_bugs_done = 0
             for module_name in module_names:
                 k = (module_name, check.__name__)
-                if not k in self.bugs or not check.__name__ in results[module_name]['results']:
+                if k not in self.bugs or check.__name__ not in results[module_name]['results']:
                     continue
                 nb_with_bugs += 1
                 if results[module_name]['results'][check.__name__][0] == 'ok':
@@ -677,10 +680,10 @@ class cmd_goalreport(Command):
                 filename += '?action=raw'
             try:
                 filename = httpcache.load(filename, age=0)
-            except Exception, e:
+            except Exception as e:
                 logging.warning('could not download %s: %s' % (filename, e))
                 return
-        for line in file(filename):
+        for line in open(filename):
             line = line.strip()
             if not line:
                 continue
@@ -724,10 +727,10 @@ class cmd_goalreport(Command):
                 filename += '?action=raw'
             try:
                 filename = httpcache.load(filename, age=0)
-            except Exception, e:
+            except Exception as e:
                 logging.warning('could not download %s: %s' % (filename, e))
                 return
-        for line in file(filename):
+        for line in open(filename):
             line = line.strip()
             if not line:
                 continue
@@ -755,7 +758,7 @@ class cmd_goalreport(Command):
         if not curses:
             return
         columns = curses.tigetnum('cols')
-        width = columns / 2
+        width = columns // 2
         num_hashes = int(round(progress * width))
         progress_bar = '[' + (num_hashes * '=') + ((width - num_hashes) * '-') + ']'
 
