@@ -26,7 +26,8 @@ import errno
 
 from jhbuild.errors import FatalError, BuildStateError
 from jhbuild.modtypes import \
-     Package, register_module_type
+     register_module_type, MakeModule, get_branch
+from jhbuild.utils import _
 
 __all__ = [ 'LinuxModule' ]
 
@@ -45,7 +46,7 @@ class LinuxConfig:
                 raise BuildStateError(_('kconfig file %s was not created') % self.path)
 
 
-class LinuxModule(Package):
+class LinuxModule(MakeModule):
     '''For modules that are built with the linux kernel method of
     make config, make, make install and make modules_install.'''
     type = 'linux'
@@ -62,9 +63,8 @@ class LinuxModule(Package):
     PHASE_INSTALL         = 'install'
 
     def __init__(self, name, branch=None, kconfigs=None, makeargs=None):
-        Package.__init__(self, name, branch=branch)
+        MakeModule.__init__(self, name, branch=branch, makeargs=makeargs)
         self.kconfigs = kconfigs
-        self.makeargs = makeargs
 
     def get_srcdir(self, buildscript):
         return self.branch.srcdir
@@ -90,15 +90,12 @@ class LinuxModule(Package):
         self.branch.force_checkout(buildscript)
     do_force_checkout.error_phases = [PHASE_FORCE_CHECKOUT, PHASE_MRPROPER]
 
-    def get_makeargs(self):
-        return self.makeargs + ' ' + self.config.module_makeargs.get(self.name, self.config.makeargs)
-
     def do_mrproper(self, buildscript):
         buildscript.set_action(_('make mrproper'), self)
         for kconfig in self.kconfigs:
             cmd = '%s %s mrproper EXTRAVERSION=%s O=%s' % (
                     os.environ.get('MAKE', 'make'),
-                    self.get_makeargs(),
+                    self.get_makeargs(buildscript),
                     kconfig.version,
                     'build-' + kconfig.version)
             buildscript.execute(cmd, cwd = self.branch.srcdir,
@@ -118,8 +115,8 @@ class LinuxModule(Package):
 
             try:
                 os.makedirs(os.path.join(self.branch.srcdir, 'build-' + kconfig.version))
-            except OSError, (e, msg):
-                if e != errno.EEXIST:
+            except OSError as e:
+                if e.errno != errno.EEXIST:
                     raise
 
             if kconfig.branch:
@@ -146,7 +143,7 @@ class LinuxModule(Package):
         for kconfig in self.kconfigs:
             cmd = '%s %s clean EXTRAVERSION=%s O=%s' % (
                     os.environ.get('MAKE', 'make'),
-                    self.get_makeargs(),
+                    self.get_makeargs(buildscript),
                     kconfig.version,
                     'build-' + kconfig.version)
             buildscript.execute(cmd, cwd = self.branch.srcdir,
@@ -158,7 +155,7 @@ class LinuxModule(Package):
         buildscript.set_action(_('Building'), self)
         for kconfig in self.kconfigs:
             cmd = '%s %s EXTRAVERSION=%s O=%s' % (os.environ.get('MAKE', 'make'),
-                                                  self.get_makeargs(),
+                                                  self.get_makeargs(buildscript),
                                                   kconfig.version,
                                                   'build-' + kconfig.version)
             buildscript.execute(cmd, cwd = self.branch.srcdir,
@@ -190,7 +187,7 @@ class LinuxModule(Package):
         for kconfig in self.kconfigs:
             cmd = '%s %s modules_install EXTRAVERSION=%s O=%s INSTALL_MOD_PATH=%s' % (
                     os.environ.get('MAKE', 'make'),
-                    self.get_makeargs(),
+                    self.get_makeargs(buildscript),
                     kconfig.version,
                     'build-' + kconfig.version,
                     buildscript.config.prefix)
@@ -205,7 +202,7 @@ class LinuxModule(Package):
         for kconfig in self.kconfigs:
             cmd = '%s %s headers_install EXTRAVERSION=%s O=%s INSTALL_HDR_PATH=%s' % (
                     os.environ.get('MAKE', 'make'),
-                    self.get_makeargs(),
+                    self.get_makeargs(buildscript),
                     kconfig.version,
                     'build-' + kconfig.version,
                     buildscript.config.prefix)
@@ -231,6 +228,7 @@ def get_kconfigs(node, repositories, default_repo):
     id = node.getAttribute('id')
 
     kconfigs = []
+    kconfig = None
 
     for childnode in node.childNodes:
         if childnode.nodeType != childnode.ELEMENT_NODE or childnode.nodeName != 'kconfig':
@@ -242,7 +240,7 @@ def get_kconfigs(node, repositories, default_repo):
                 repo = repositories[repo_name]
             except KeyError:
                 raise FatalError(_('Repository=%(missing)s not found for kconfig in linux id=%(linux_id)s. Possible repositories are %(possible)s'
-                                    % {'missing': repo_name, 'linux_id': id, 'possible': repositories}))
+                                   % {'missing': repo_name, 'linux_id': id, 'possible': repositories}))
         else:
             try:
                 repo = repositories[default_repo]
@@ -276,10 +274,9 @@ def parse_linux(node, config, uri, repositories, default_repo):
         makeargs = node.getAttribute('makeargs')
         makeargs = makeargs.replace('${prefix}', config.prefix)
 
-    dependencies, after, suggests = get_dependencies(node)[0:2]
     branch = get_branch(node, repositories, default_repo, config)
     kconfigs = get_kconfigs(node, repositories, default_repo)
 
-    return LinuxModule(id, branch, dependencies, after, suggests, kconfigs, makeargs)
+    return LinuxModule(id, branch, kconfigs, makeargs)
 
 register_module_type('linux', parse_linux)
