@@ -21,12 +21,7 @@ __all__ = []
 __metaclass__ = type
 
 import os
-try:
-    import hashlib
-except ImportError:
-    import md5 as hashlib
-import urlparse
-import urllib2
+import hashlib
 import logging
 import zipfile
 
@@ -35,8 +30,9 @@ from jhbuild.versioncontrol import Repository, Branch, register_repo_type
 from jhbuild.utils.cmds import has_command, get_output
 from jhbuild.modtypes import get_branch
 from jhbuild.utils.unpack import unpack_archive
-from jhbuild.utils import httpcache
+from jhbuild.utils import httpcache, _
 from jhbuild.utils.sxml import sxml
+from jhbuild.utils import urlutils
 
 
 class TarballRepository(Repository):
@@ -66,18 +62,18 @@ class TarballRepository(Repository):
             module = self.config.branches[name]
             if not module:
                 raise FatalError(_('branch for %(name)s has wrong override, check your %(filename)s') % \
-                                   {'name'     : name,
-                                    'filename' : self.config.filename})
+                                 {'name'     : name,
+                                  'filename' : self.config.filename})
         else:
             if module is None:
                 module = name
-            module = urlparse.urljoin(self.href, module)
+            module = urlutils.urljoin(self.href, module)
         module = module.replace('${version}', version)
         if checkoutdir is not None:
             checkoutdir = checkoutdir.replace('${version}', version)
         if size is not None:
             size = int(size)
-        if md5sum and (not hash or hashlib.__name__ == 'md5'):
+        if md5sum and not hash:
             hash = 'md5:' + md5sum
         if rename_tarball is not None:
             rename_tarball = rename_tarball.replace('${name}', name).replace('${version}', version)
@@ -94,7 +90,8 @@ class TarballRepository(Repository):
             raise FatalError(_('branch for %s is not correct, check the moduleset file.') % name)
         # patches represented as children of the branch node
         for childnode in branchnode.childNodes:
-            if childnode.nodeType != childnode.ELEMENT_NODE: continue
+            if childnode.nodeType != childnode.ELEMENT_NODE:
+                continue
             if childnode.nodeName == 'patch':
                 patchfile = childnode.getAttribute('file')
                 if childnode.hasAttribute('strip'):
@@ -126,6 +123,7 @@ class TarballBranch(Branch):
         self.source_subdir = source_subdir
         self.tarball_name = tarball_name
 
+    @property
     def _local_tarball(self):
         if self.tarball_name:
             return os.path.join(self.config.tarballdir, self.tarball_name)
@@ -134,8 +132,8 @@ class TarballBranch(Branch):
             raise FatalError(_('URL has no filename component: %s') % self.module)
         localfile = os.path.join(self.config.tarballdir, basename)
         return localfile
-    _local_tarball = property(_local_tarball)
 
+    @property
     def raw_srcdir(self):
         if self.checkoutdir:
             return os.path.join(self.checkoutroot, self.checkoutdir)
@@ -158,17 +156,16 @@ class TarballBranch(Branch):
         if localdir.endswith('.src'):
             localdir = localdir[:-4]
         return localdir
-    raw_srcdir = property(raw_srcdir)
 
+    @property
     def srcdir(self):
         if self.source_subdir:
             return os.path.join(self.raw_srcdir, self.source_subdir)
         return self.raw_srcdir
-    srcdir = property(srcdir)
 
+    @property
     def branchname(self):
         return self.version
-    branchname = property(branchname)
 
     def _check_tarball(self):
         """Check whether the tarball has been downloaded correctly."""
@@ -238,7 +235,7 @@ class TarballBranch(Branch):
             self._check_tarball()
         except BuildStateError:
             # don't have the tarball, try downloading it and check again
-            res = self._download_tarball(buildscript, localfile)
+            self._download_tarball(buildscript, localfile)
             self._check_tarball()
 
         # now to unpack it
@@ -260,23 +257,23 @@ class TarballBranch(Branch):
         # now patch the working tree
         for (patch, patchstrip) in self.patches:
             patchfile = ''
-            if urlparse.urlparse(patch)[0]:
+            if urlutils.urlparse(patch)[0]:
                 # patch name has scheme, get patch from network
                 try:
                     patchfile = httpcache.load(patch, nonetwork=buildscript.config.nonetwork)
-                except urllib2.HTTPError as e:
+                except urlutils.HTTPError as e:
                     raise BuildStateError(_('could not download patch (error: %s)') % e.code)
-                except urllib2.URLError as e:
+                except urlutils.URLError:
                     raise BuildStateError(_('could not download patch'))
             elif self.repository.moduleset_uri:
                 # get it relative to the moduleset uri, either in the same
                 # directory or a patches/ subdirectory
                 for patch_prefix in ('.', 'patches', '../patches'):
-                    uri = urlparse.urljoin(self.repository.moduleset_uri,
+                    uri = urlutils.urljoin(self.repository.moduleset_uri,
                             os.path.join(patch_prefix, patch))
                     try:
                         patchfile = httpcache.load(uri, nonetwork=buildscript.config.nonetwork)
-                    except Exception as e:
+                    except Exception:
                         continue
                     if not os.path.isfile(patchfile):
                         continue
@@ -371,11 +368,11 @@ class TarballBranch(Branch):
         md5sum = hashlib.md5()
         if self.patches:
             for patch in self.patches:
-                md5sum.update(patch[0])
+                md5sum.update(patch[0].encode("utf-8"))
         if self.quilt:
             md5sum.update(get_output('quilt files',
                         cwd=self.srcdir,
-                        extra_env={'QUILT_PATCHES' : self.quilt.srcdir}))
+                        extra_env={'QUILT_PATCHES' : self.quilt.srcdir}).encode("utf-8"))
         return '%s-%s' % (self.version, md5sum.hexdigest())
 
     def to_sxml(self):
